load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"
;--------------------------------------------------------------
; Test reading of refcst geopotential height data. 
;--------------------------------------------------------------
begin

; set parameters.
  mmddhh = "121500"
  yr = "2003"
  flev = 500
  nfcst = 9

; open file
  path="/nas/headnode1/jsw/ensdata/"+yr+mmddhh+"/"
  hgtspecfile = addfile(path+"hgt.refcst_ens.spec."+mmddhh+"."+yr+".nc" ,"r")

; Read spectral data
; forecasts
; (members, time, level, coefficients)
  hgtspec_r_ens = hgtspecfile->hgtspec_real(:,nfcst,{flev},:)
  hgtspec_i_ens = hgtspecfile->hgtspec_imag(:,nfcst,{flev},:)
; ens mean
  hgtspec_r = dim_avg(hgtspec_r_ens(coefficients | : , members | :))
  hgtspec_i = dim_avg(hgtspec_i_ens(coefficients | : , members | :))
; spectral indices
  m_order   = hgtspecfile->m_order
  n_degree  = hgtspecfile->n_degree

; 2.5 degree fixed lat/lon grid for T62 simulation.
  nlat = 73
  nlon = 144
  ncoeffs = dimsizes(hgtspec_r)

  N = nlat
  if (nlon%2 .eq.0) then ; nlon even
    N = min((/ nlat, (nlon+2)/2 /))
  else                   ; nlon odd
    N = min((/ nlat, (nlon+1)/2 /))
  end if

  abhgt = new ( (/2,nlat,N/), float)  ; real and imaginary coefficient data
  abhgt = 0.0                         ; important - must initialize

; Degree and order vectors determine the 2D array indices of coefficients
  do i = 0, ncoeffs-1
   abhgt(0,n_degree(i),m_order(i)) = hgtspec_r(i)
   abhgt(1,n_degree(i),m_order(i)) = hgtspec_i(i)
  end do

; Synthesize coefficients to a fixed lat/lon grid
  hgt = shseC (abhgt,nlon) 

  hgt!0 = "lat"
  hgt!1 = "lon"

;Attach lat/lon data for mapping
  lat = fspan(-90.0,90.0,nlat)
  lat@units = "degrees_north"
  lon = fspan(0.0,360.0*(nlon-1)/nlon,nlon)
  lon@units = "degrees_east"
  hgt&lat = lat
  hgt&lat = lat
  hgt&lon = lon
  hgt&lon = lon

  printVarSummary(hgt)

; plot hgt
  wks = gsn_open_wks("x11","refcsthgt")
  res                  = True                ; plot mods desired
  res@gsnDraw          = False                ; required to make
  res@gsnFrame         = False                ; contour style changes
  plot = gsn_csm_contour_map_ce(wks,hgt,res)
  plot = ZeroNegDashLineContour(plot)
  draw (plot)                                   ; draw the contour object
  frame (wks)                                   ; advance frame

end
