load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_code.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/gsn_csm.ncl"  
load "$NCARG_ROOT/lib/ncarg/nclscripts/csm/shea_util.ncl"
;--------------------------------------------------------------
; Test reading of refcst spectral vort,div coefficient data. 
;--------------------------------------------------------------
begin

; set parameters.
  mmddhh = "121500"
  yr = "2003"
  flev = 250
  nfcst = 9

; open file
  path="/nas/headnode1/jsw/ensdata/"+yr+mmddhh+"/"
  specvr_dataf = addfile(path+"vort.refcst_ens.spec."+mmddhh+"."+yr+".nc" ,"r")
  specdv_dataf = addfile(path+"div.refcst_ens.spec."+mmddhh+"."+yr+".nc" ,"r")

; Read spectral data
; forecasts
; (members, time, level, coefficients)
  specvrf_r_ens = specvr_dataf->vortspec_real(:,nfcst,{flev},:)
  specvrf_i_ens = specvr_dataf->vortspec_imag(:,nfcst,{flev},:)
  specdvf_r_ens = specdv_dataf->divspec_real(:,nfcst,{flev},:)
  specdvf_i_ens = specdv_dataf->divspec_imag(:,nfcst,{flev},:)
; ens mean
  specvrf_r = dim_avg(specvrf_r_ens(coefficients | : , members | :))
  specvrf_i = dim_avg(specvrf_i_ens(coefficients | : , members | :))
  specdvf_r = dim_avg(specdvf_r_ens(coefficients | : , members | :))
  specdvf_i = dim_avg(specdvf_i_ens(coefficients | : , members | :))
; spectral indices
  m_order   = specvr_dataf->m_order
  n_degree  = specvr_dataf->n_degree

; 2.5 degree fixed lat/lon grid for T62 simulation.
  nlat = 73
  nlon = 144
  ncoeffs = dimsizes(specvrf_r)

  N = nlat
  if (nlon%2 .eq.0) then ; nlon even
    N = min((/ nlat, (nlon+2)/2 /))
  else                   ; nlon odd
    N = min((/ nlat, (nlon+1)/2 /))
  end if

  abvrf = new ( (/2,nlat,N/), float)  ; real and imaginary coefficient data
  abdvf = new ( (/2,nlat,N/), float)  ; real and imaginary coefficient data
  abvrf = 0.0                         ; important - must initialize
  abdvf = 0.0                         ; important - must initialize

; Degree and order vectors determine the 2D array indices of coefficients
  do i = 0, ncoeffs-1
   abvrf(0,n_degree(i),m_order(i)) = specvrf_r(i)
   abvrf(1,n_degree(i),m_order(i)) = specvrf_i(i)
   abdvf(0,n_degree(i),m_order(i)) = specdvf_r(i)
   abdvf(1,n_degree(i),m_order(i)) = specdvf_i(i)
  end do

; Synthesize coefficients to a fixed lat/lon grid
  divf = shseC (abdvf,nlon) 
  vrtf = shseC (abvrf,nlon) 
; compute u,v from vort,div
  uvf = vrdv2uvF(vrtf,divf)
  uf = uvf(0,:,:)
  vf = uvf(1,:,:)

  uf!0 = "lat"
  uf!1 = "lon"
  vf!0 = "lat"
  vf!1 = "lon"

;Attach lat/lon data for mapping
  lat = fspan(-90.0,90.0,nlat)
  lat@units = "degrees_north"
  lon = fspan(0.0,360.0*(nlon-1)/nlon,nlon)
  lon@units = "degrees_east"
  uf&lat = lat
  vf&lat = lat
  uf&lon = lon
  vf&lon = lon

  printVarSummary(uf)
  printVarSummary(vf)

; plot zonal wind.
  wks = gsn_open_wks("x11","refcstwind")
  res                  = True                ; plot mods desired
  res@gsnDraw          = False                ; required to make
  res@gsnFrame         = False                ; contour style changes
  plot = gsn_csm_contour_map_ce(wks,uf,res)
  plot = ZeroNegDashLineContour(plot)
  draw (plot)                                   ; draw the contour object
  frame (wks)                                   ; advance frame

end
